"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Wysiwyg = void 0;
const React = __importStar(require("react"));
const design_system_1 = require("@strapi/design-system");
const helper_plugin_1 = require("@strapi/helper-plugin");
const react_intl_1 = require("react-intl");
const styled_components_1 = __importDefault(require("styled-components"));
const Hint_1 = require("../Hint");
const Editor_1 = require("./Editor");
const EditorLayout_1 = require("./EditorLayout");
const utils_1 = require("./utils/utils");
const WysiwygFooter_1 = require("./WysiwygFooter");
const WysiwygNav_1 = require("./WysiwygNav");
const Wysiwyg = React.forwardRef(({ hint, disabled, error, intlLabel, labelAction, name, onChange, placeholder, value, required }, forwardedRef) => {
    const { formatMessage } = (0, react_intl_1.useIntl)();
    const textareaRef = React.useRef(null);
    const editorRef = React.useRef(null);
    const [isPreviewMode, setIsPreviewMode] = React.useState(false);
    const [mediaLibVisible, setMediaLibVisible] = React.useState(false);
    const [isExpandMode, setIsExpandMode] = React.useState(false);
    const { components = {} } = (0, helper_plugin_1.useLibrary)();
    const MediaLibraryDialog = components['media-library'];
    const handleToggleMediaLib = () => setMediaLibVisible((prev) => !prev);
    const handleTogglePreviewMode = () => setIsPreviewMode((prev) => !prev);
    const handleToggleExpand = () => {
        setIsPreviewMode(false);
        setIsExpandMode((prev) => !prev);
    };
    const handleActionClick = (value, currentEditorRef, togglePopover) => {
        switch (value) {
            case 'Link':
            case 'Strikethrough': {
                (0, utils_1.markdownHandler)(currentEditorRef, value);
                togglePopover?.();
                break;
            }
            case 'Code':
            case 'Quote': {
                (0, utils_1.quoteAndCodeHandler)(currentEditorRef, value);
                togglePopover?.();
                break;
            }
            case 'Bold':
            case 'Italic':
            case 'Underline': {
                (0, utils_1.markdownHandler)(currentEditorRef, value);
                break;
            }
            case 'BulletList':
            case 'NumberList': {
                (0, utils_1.listHandler)(currentEditorRef, value);
                togglePopover?.();
                break;
            }
            case 'h1':
            case 'h2':
            case 'h3':
            case 'h4':
            case 'h5':
            case 'h6': {
                (0, utils_1.titleHandler)(currentEditorRef, value);
                break;
            }
            default: {
            }
        }
    };
    const handleSelectAssets = (files) => {
        const formattedFiles = files.map((f) => ({
            alt: f.alternativeText || f.name,
            url: (0, helper_plugin_1.prefixFileUrlWithBackendUrl)(f.url),
            mime: f.mime,
        }));
        (0, utils_1.insertFile)(editorRef, formattedFiles);
        setMediaLibVisible(false);
    };
    const formattedPlaceholder = placeholder
        ? formatMessage({ id: placeholder.id, defaultMessage: placeholder.defaultMessage }, { ...placeholder.values })
        : '';
    const label = intlLabel.id
        ? formatMessage({ id: intlLabel.id, defaultMessage: intlLabel.defaultMessage }, { ...intlLabel.values })
        : name;
    return (React.createElement(React.Fragment, null,
        React.createElement(design_system_1.Flex, { direction: "column", alignItems: "stretch", gap: 1 },
            React.createElement(design_system_1.Flex, { gap: 1 },
                React.createElement(design_system_1.Typography, { variant: "pi", fontWeight: "bold", textColor: "neutral800" },
                    label,
                    required && React.createElement(TypographyAsterisk, { textColor: "danger600" }, "*")),
                labelAction && React.createElement(LabelAction, { paddingLeft: 1 }, labelAction)),
            React.createElement(EditorLayout_1.EditorLayout, { isExpandMode: isExpandMode, error: error, previewContent: value, onCollapse: handleToggleExpand },
                React.createElement(WysiwygNav_1.WysiwygNav, { isExpandMode: isExpandMode, editorRef: editorRef, isPreviewMode: isPreviewMode, onActionClick: handleActionClick, onToggleMediaLib: handleToggleMediaLib, onTogglePreviewMode: isExpandMode ? undefined : handleTogglePreviewMode, disabled: disabled }),
                React.createElement(Editor_1.Editor, { disabled: disabled, isExpandMode: isExpandMode, editorRef: editorRef, error: error, isPreviewMode: isPreviewMode, name: name, onChange: onChange, placeholder: formattedPlaceholder, textareaRef: textareaRef, value: value, ref: forwardedRef }),
                !isExpandMode && React.createElement(WysiwygFooter_1.WysiwygFooter, { onToggleExpand: handleToggleExpand })),
            React.createElement(Hint_1.Hint, { hint: hint, name: name, error: error })),
        error && (React.createElement(design_system_1.Box, { paddingTop: 1 },
            React.createElement(design_system_1.Typography, { variant: "pi", textColor: "danger600", "data-strapi-field-error": true }, error))),
        mediaLibVisible && (React.createElement(MediaLibraryDialog, { onClose: handleToggleMediaLib, onSelectAssets: handleSelectAssets }))));
});
exports.Wysiwyg = Wysiwyg;
const LabelAction = (0, styled_components_1.default)(design_system_1.Box) `
  svg path {
    fill: ${({ theme }) => theme.colors.neutral500};
  }
`;
const TypographyAsterisk = (0, styled_components_1.default)(design_system_1.Typography) `
  line-height: 0;
`;
//# sourceMappingURL=Field.js.map